@@ -1,26 +1,26 @@
 ### R code from vignette source 'twang.rnw'
 
 ###################################################
-### code chunk number 1: twang.rnw:100-101
+### code chunk number 1: twang.rnw:104-105
 ###################################################
 options(width=60)
 
 
 ###################################################
-### code chunk number 2: twang.rnw:120-122
+### code chunk number 2: twang.rnw:124-126
 ###################################################
 library(twang)
 set.seed(1)
 
 
 ###################################################
-### code chunk number 3: twang.rnw:130-131
+### code chunk number 3: twang.rnw:134-135
 ###################################################
 data(lalonde)
 
 
 ###################################################
-### code chunk number 4: twang.rnw:154-164
+### code chunk number 4: twang.rnw:158-168
 ###################################################
 ps.lalonde <- ps(treat ~ age + educ + black + hispan + nodegree +
                          married + re74 + re75,
@@ -47,7 +47,7 @@ ps.lalonde <- ps(treat ~ age + educ + black + hispan + nodegree +
 
 
 ###################################################
-### code chunk number 7: twang.rnw:361-364
+### code chunk number 7: twang.rnw:366-369
 ###################################################
 summary(ps.lalonde$gbm.obj,
         n.trees=ps.lalonde$desc$ks.max.ATT$n.trees,
@@ -55,33 +55,33 @@ summary(ps.lalonde$gbm.obj,
 
 
 ###################################################
-### code chunk number 8: twang.rnw:370-372
+### code chunk number 8: twang.rnw:375-377
 ###################################################
 summary(ps.lalonde$gbm.obj,
         n.trees=ps.lalonde$desc$ks.max.ATT$n.trees)
 
 
 ###################################################
-### code chunk number 9: twang.rnw:401-402
+### code chunk number 9: twang.rnw:406-407
 ###################################################
 options(width=85)
 
 
 ###################################################
-### code chunk number 10: twang.rnw:405-407
+### code chunk number 10: twang.rnw:410-412
 ###################################################
 lalonde.balance <- bal.table(ps.lalonde)
 lalonde.balance
 
 
 ###################################################
-### code chunk number 11: twang.rnw:410-411
+### code chunk number 11: twang.rnw:415-416
 ###################################################
 options(width=60)
 
 
 ###################################################
-### code chunk number 12: twang.rnw:484-493
+### code chunk number 12: twang.rnw:489-498
 ###################################################
 library(xtable)
 pretty.tab <- lalonde.balance$ks.max.ATT[,c("tx.mn","ct.mn","ks")]
@@ -95,76 +95,76 @@ xtable(pretty.tab,
 
 
 ###################################################
-### code chunk number 13: twang.rnw:507-508
+### code chunk number 13: twang.rnw:512-513
 ###################################################
 summary(ps.lalonde)
 
 
 ###################################################
-### code chunk number 14: twang.rnw:584-585
+### code chunk number 14: twang.rnw:589-590
 ###################################################
 plot(ps.lalonde, plots=2)
 
 
 ###################################################
-### code chunk number 15: twang.rnw:630-631
+### code chunk number 15: twang.rnw:635-636
 ###################################################
 plot(ps.lalonde, plots=3)
 
 
 ###################################################
-### code chunk number 16: twang.rnw:645-646
+### code chunk number 16: twang.rnw:651-652
 ###################################################
 plot(ps.lalonde, plots = 4)
 
 
 ###################################################
-### code chunk number 17: twang.rnw:661-662
+### code chunk number 17: twang.rnw:667-668
 ###################################################
 plot(ps.lalonde, plots = 5)
 
 
 ###################################################
-### code chunk number 18: twang.rnw:697-698
+### code chunk number 18: twang.rnw:703-704
 ###################################################
 plot(ps.lalonde, plots = 3, subset = 2)
 
 
 ###################################################
-### code chunk number 19: twang.rnw:714-715
+### code chunk number 19: twang.rnw:718-719
 ###################################################
 library(survey)
 
 
 ###################################################
-### code chunk number 20: twang.rnw:727-729
+### code chunk number 20: twang.rnw:731-733
 ###################################################
 lalonde$w <- get.weights(ps.lalonde, stop.method="es.mean")
 design.ps <- svydesign(ids=~1, weights=~w, data=lalonde)
 
 
 ###################################################
-### code chunk number 21: twang.rnw:732-732
+### code chunk number 21: twang.rnw:736-736
 ###################################################
 
 
 
 ###################################################
-### code chunk number 22: twang.rnw:765-767
+### code chunk number 22: twang.rnw:770-772
 ###################################################
 glm1 <- svyglm(re78 ~ treat, design=design.ps)
 summary(glm1)
 
 
 ###################################################
-### code chunk number 23: twang.rnw:798-800
+### code chunk number 23: twang.rnw:804-806
 ###################################################
 glm2 <- svyglm(re78 ~ treat + nodegree, design=design.ps)
 summary(glm2)
 
 
 ###################################################
-### code chunk number 24: twang.rnw:812-816
+### code chunk number 24: twang.rnw:818-822
 ###################################################
 glm3 <- svyglm(re78 ~ treat + age + educ + black + hispan + nodegree +
                       married + re74 + re75,
@@ -173,7 +173,7 @@ summary(glm3)
 
 
 ###################################################
-### code chunk number 25: twang.rnw:825-829
+### code chunk number 25: twang.rnw:831-835
 ###################################################
 glm4 <- lm(re78 ~ treat + age + educ + black + hispan + nodegree +
                   married + re74 + re75,
@@ -182,7 +182,7 @@ summary(glm4)
 
 
 ###################################################
-### code chunk number 26: twang.rnw:832-835
+### code chunk number 26: twang.rnw:838-841
 ###################################################
 glm5 <- lm(sqrt(re78) ~ treat + age + educ + black + hispan + nodegree +
                         married + sqrt(re74) + sqrt(re75),
@@ -190,7 +190,7 @@ glm5 <- lm(sqrt(re78) ~ treat + age + educ + black + hispan + nodegree +
 
 
 ###################################################
-### code chunk number 27: twang.rnw:860-866
+### code chunk number 27: twang.rnw:867-873
 ###################################################
 ps.logit <- glm(treat ~ age + educ + black + hispan + nodegree +
                         married + re74 + re75,
@@ -201,7 +201,7 @@ lalonde$w.logit[lalonde$treat==0] <- exp(predict(ps.logit,subset(lalonde,treat==
 
 
 ###################################################
-### code chunk number 28: twang.rnw:880-887
+### code chunk number 28: twang.rnw:887-894
 ###################################################
 bal.logit <- dx.wts(x = lalonde$w.logit,
                     data=lalonde,
@@ -213,15 +213,19 @@ bal.logit
 
 
 ###################################################
-### code chunk number 29: twang.rnw:895-898
+### code chunk number 29: twang.rnw:902-909
 ###################################################
-
-bal.tab.logit <- bal.table(bal.logit)
-bal.tab.logit
+bal.logit <- dx.wts(x = lalonde$w.logit,
+                    data=lalonde,
+                    vars=c("age","educ","black","hispan","nodegree",
+                      "married","re74","re75"),
+                    treat.var="treat",
+                    perm.test.iters=0, estimand = "ATT")
+bal.logit
 
 
 ###################################################
-### code chunk number 30: twang.rnw:910-918
+### code chunk number 30: twang.rnw:921-929
 ###################################################
 pretty.tab <- bal.table(bal.logit)[[2]][,c("tx.mn","ct.mn","ks")]
 pretty.tab <- cbind(pretty.tab, bal.table(bal.logit)[[1]]$ct.mn)
@@ -234,7 +238,7 @@ xtable(pretty.tab,
 
 
 ###################################################
-### code chunk number 31: twang.rnw:928-945
+### code chunk number 31: twang.rnw:939-956
 ###################################################
 bal.gbm <- dx.wts(ps.lalonde,
                   data=lalonde, estimand = "ATE",
@@ -256,7 +260,7 @@ xtable(pretty.tab,
 
 
 ###################################################
-### code chunk number 32: twang.rnw:948-951
+### code chunk number 32: twang.rnw:959-962
 ###################################################
 design.logit <- svydesign(ids=~1, weights=~w.logit, data=lalonde)
 glm6 <- svyglm(re78 ~ treat, design=design.logit)
@@ -264,7 +268,7 @@ summary(glm6)
 
 
 ###################################################
-### code chunk number 33: twang.rnw:961-964
+### code chunk number 33: twang.rnw:975-978
 ###################################################
 glm7 <- svyglm(re78 ~ treat + age + educ + black + hispan + nodegree +
                       married + re74 + re75,
@@ -272,7 +276,7 @@ glm7 <- svyglm(re78 ~ treat + age + educ + black + hispan + nodegree +
 
 
 ###################################################
-### code chunk number 34: twang.rnw:1044-1047
+### code chunk number 34: twang.rnw:1057-1060
 ###################################################
 data(lindner)
 table(lindner$sixMonthSurvive, lindner$abcix)
@@ -280,7 +284,7 @@ chisq.test(table(lindner$sixMonthSurvive, lindner$abcix))
 
 
 ###################################################
-### code chunk number 35: twang.rnw:1057-1061
+### code chunk number 35: twang.rnw:1071-1075
 ###################################################
 set.seed(1)
 ps.lindner <- ps(abcix ~ stent + height + female + diabetic + 
@@ -289,61 +293,61 @@ ps.lindner <- ps(abcix ~ stent + height + female + diabetic +
 
 
 ###################################################
-### code chunk number 36: twang.rnw:1071-1072
+### code chunk number 36: twang.rnw:1087-1088
 ###################################################
 options(width=85)
 
 
 ###################################################
-### code chunk number 37: twang.rnw:1075-1076
+### code chunk number 37: twang.rnw:1091-1092
 ###################################################
 bal.table(ps.lindner)
 
 
 ###################################################
-### code chunk number 38: twang.rnw:1079-1080
+### code chunk number 38: twang.rnw:1095-1096
 ###################################################
 options(width = 60)
 
 
 ###################################################
-### code chunk number 39: twang.rnw:1101-1102
+### code chunk number 39: twang.rnw:1118-1119
 ###################################################
 plot(ps.lindner, plots = 1)
 
 
 ###################################################
-### code chunk number 40: twang.rnw:1110-1111
+### code chunk number 40: twang.rnw:1126-1127
 ###################################################
 plot(ps.lindner, plots = 2)
 
 
 ###################################################
-### code chunk number 41: twang.rnw:1117-1118
+### code chunk number 41: twang.rnw:1133-1134
 ###################################################
 plot(ps.lindner, plots = 3)
 
 
 ###################################################
-### code chunk number 42: twang.rnw:1125-1126
+### code chunk number 42: twang.rnw:1141-1142
 ###################################################
 plot(ps.lindner, plots = 4)
 
 
 ###################################################
-### code chunk number 43: twang.rnw:1132-1133
+### code chunk number 43: twang.rnw:1148-1149
 ###################################################
 plot(ps.lindner, plots = 5)
 
 
 ###################################################
-### code chunk number 44: twang.rnw:1145-1146
+### code chunk number 44: twang.rnw:1162-1163
 ###################################################
 summary(ps.lindner)
 
 
 ###################################################
-### code chunk number 45: twang.rnw:1152-1155
+### code chunk number 45: twang.rnw:1170-1173
 ###################################################
 lindner$w <- get.weights(ps.lindner, stop.method = "es.mean")
 design.ps <- svydesign(ids=~1, weights = ~w, data = lindner)
@@ -351,86 +355,119 @@ svychisq(~sixMonthSurvive + abcix, design = design.ps)
 
 
 ###################################################
-### code chunk number 46: twang.rnw:1238-1239
+### code chunk number 46: twang.rnw:1233-1234
 ###################################################
 data(egsingle)
 
 
 ###################################################
-### code chunk number 47: twang.rnw:1245-1247
+### code chunk number 47: twang.rnw:1242-1243
 ###################################################
-tmp <- sapply(split(egsingle,egsingle$childid),function(x){
-              paste(as.character(x$grade),collapse="")})
+tmp <- tapply(egsingle$grade, egsingle$childid, unique) 
 
 
 ###################################################
-### code chunk number 48: twang.rnw:1251-1254
+### code chunk number 48: twang.rnw:1251-1252
 ###################################################
-tmp <- data.frame(childid=names(tmp), gpatt=tmp,
-                  resp=as.numeric((1:length(tmp)) %in%
-                          grep("1234",as.character(tmp))))
+tmp <- lapply(tmp, function(x){return(x %in% 1:4)})
 
 
 ###################################################
-### code chunk number 49: twang.rnw:1258-1259
+### code chunk number 49: twang.rnw:1259-1260
 ###################################################
-egsingle <- merge(egsingle, tmp)
+tmp <- lapply(tmp, sum)
 
 
 ###################################################
 ### code chunk number 50: twang.rnw:1265-1266
 ###################################################
+tmp <- sapply(tmp, function(x){as.numeric(x == 4)})
+
+
+###################################################
+### code chunk number 51: twang.rnw:1271-1274
+###################################################
+tmp <- data.frame(tmp)
+names(tmp) <- "resp"
+tmp$childid <- row.names(tmp)
+
+
+###################################################
+### code chunk number 52: twang.rnw:1279-1280
+###################################################
+egsingle <- merge(egsingle, tmp)
+
+
+###################################################
+### code chunk number 53: twang.rnw:1287-1288
+###################################################
 egsingle.one <-unique(egsingle[,-c(3:6)])
 
 
 ###################################################
-### code chunk number 51: twang.rnw:1271-1273
+### code chunk number 54: twang.rnw:1293-1295
 ###################################################
 egsingle.one$race <- as.factor(race <- ifelse(egsingle.one$black==1, 1,
                                          ifelse(egsingle.one$hispanic==1, 2, 3)))
 
 
 ###################################################
-### code chunk number 52: twang.rnw:1285-1292
+### code chunk number 55: twang.rnw:1307-1313
 ###################################################
-egsingle.ps <-
-   ps(resp ~ race + female + size + lowinc + mobility,
+egsingle.ps <-  ps(resp ~ race + female + size + lowinc + mobility,
       data=egsingle.one,
       stop.method=c("es.mean","ks.max"),
-      n.trees=2500,
+      n.trees=5000,
       verbose=FALSE,
       estimand = "ATE")
 
 
 ###################################################
-### code chunk number 53: twang.rnw:1300-1301
+### code chunk number 56: twang.rnw:1324-1325
 ###################################################
 plot(egsingle.ps)
 
 
 ###################################################
-### code chunk number 54: twang.rnw:1325-1332
-###################################################
-pretty.tab<-bal.table(egsingle.ps)$ks.max.ATE[,c("tx.mn","ct.mn","std.eff.sz","ks")]
-names(pretty.tab) <- c("Non-responders","Weighted responders","Std ES","KS")
-xtable(pretty.tab,
-       caption = "Balance of the nonrespondents and respondents",
-       label = "tab:balance2",
-       digits = c(0, 2, 2, 2, 2),
-       align=c("l","r","r","r","r"))
-
-
-###################################################
-### code chunk number 55: twang.rnw:1337-1338
+### code chunk number 57: twang.rnw:1363-1364
 ###################################################
 egsingle.one$wgt <- get.weights(egsingle.ps, stop.method="ks.max")
 
 
 ###################################################
-### code chunk number 56: twang.rnw:1343-1346
+### code chunk number 58: twang.rnw:1373-1375
 ###################################################
- egsinge.resp <- merge(subset(egsingle, subset=resp==1),
-                       subset(egsingle.one, subset=resp==1,
-                              select=c(childid, wgt)) )
+egtmp <- rbind(data.frame(egsingle.one, nr2=1, wgt2=1), 
+                data.frame(egsingle.one, nr2=0, wgt2=egsingle.one$wgt)[egsingle.one$resp==1,])
+
+
+###################################################
+### code chunk number 59: twang.rnw:1381-1386
+###################################################
+egdxwts <- dx.wts(x=egtmp$wgt2, 
+                   data=egtmp, 
+                   estimand="ATT", 
+                   vars=c("race", "female", "size",  "lowinc",  "mobility"),
+                   treat.var="nr2")
+
+
+###################################################
+### code chunk number 60: twang.rnw:1389-1396
+###################################################
+pretty.tab<-bal.table(egdxwts)[[2]][,c("tx.mn","ct.mn","std.eff.sz","ks")]
+names(pretty.tab) <- c("OverallS Sample","Weighted responders","Std ES","KS")
+xtable(pretty.tab,
+        caption = "Balance of the nonrespondents and respondents",
+        label = "tab:balance2",
+        digits = c(0, 2, 2, 2, 2),
+        align=c("l","r","r","r","r"))
+
+
+###################################################
+### code chunk number 61: twang.rnw:1405-1408
+###################################################
+egsinge.resp <- merge(subset(egsingle, subset=resp==1),
+                        subset(egsingle.one, subset=resp==1,
+                               select=c(childid, wgt)) )
 
 
